<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# db_ora portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_db_ora/master?logo=python)](
    https://gitlab.com/ae-group/ae_db_ora)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_db_ora/coverage.svg)](
    https://ae-group.gitlab.io/ae_db_ora/coverage/ae_db_ora_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_db_ora/mypy.svg)](
    https://ae-group.gitlab.io/ae_db_ora/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_db_ora/pylint.svg)](
    https://ae-group.gitlab.io/ae_db_ora/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_db_ora)](
    https://libraries.io/pypi/ae-db-ora)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_db_ora)](
    https://pypi.org/project/ae-db-ora/#files)


## installation


execute the following command to use the ae.db_ora module in your
application. it will install ae.db_ora into your python (virtual) environment:
 
```shell script
pip install ae-db-ora
```

if you instead want to contribute to this portion then first fork
[the ae_db_ora repository at GitLab](https://gitlab.com/ae-group/ae_db_ora "ae.db_ora code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_db_ora):

```shell script
pip install -e .[dev]
```

the last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.db_ora.html#module-ae.db_ora
"ae_db_ora documentation").

<!-- common files version 0.2.77 deployed version 0.2.4 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_db_ora module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-db-ora as namespace portion ae-db-ora.
-->
